==> tine20-exampleapplication_2016.11.24.tar.bz2: ExampleApplication/js/ExampleApplication-lang-pl-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0 - ExampleApplication\nReport-Msgid-Bugs-To: \nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-03-02 13:06+0000\nLast-Translator: Wojciech Kaczmarek <Unknown>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Launchpad-Export-Date: 2012-03-03 05:53+0000\nX-Generator: Launchpad (build 14886)\nX-Poedit-Language: Polish\nX-Poedit-SourceCharset: utf-8\n"

, "Status Available"
: "Status Dostępny"

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: "Możliwy status. Zauważ proszę, że dodatkowy status może wpływać w innych przykładowych aplikacjach na eksport albo synchronizację."

, "%s's personal example records"
: "%s przykładowe, osobiste wiersze"

, "Example Application test"
: "Test przykładowej aplikacji"

, "ExampleRecord"
: "Przykładowy wiersz"

, "Name"
: "Nazwa"

, "Status"
: "Status"

, "Title"
: "Tytuł"

, "Budget"
: "Budżet"

, "Show closed"
: "Pokaż zakończone"

, "example record, example records"
: [
  "Przykładowy wiersz"
 ,"przykładowe wiersze"
 ,"przykładowe wiersze"

]
, "example record list, example record lists"
: [
  "Lista przykładowych wierszy"
 ,"listy przykładowych wierszy"
 ,"listy przykładowych wierszy"

]
, "Quick Search"
: "Szybkie wyszukiwanie"

, "Last modified"
: "Ostatnio modyfikowane"

, "Last modifier"
: "Ostatnio modyfikował/a"

, "Creation Time"
: "Czas utworzenia"

, "Creator"
: "Autor"

, "Completed"
: "Zakończone"

, "Cancelled"
: "Anulowane"

, "In process"
: "W opracowaniu"

, "ExampleApplication"
: "Przykładowa aplikacja"

, "Example Application"
: "Przykładowa aplikacja"

, "ExampleRecords"
: "Przykładowe wiersze"

, "All ExampleRecords"
: "Wszystkie przykładowe wiersze"

, "Description"
: "Opis"

, "record list, record lists"
: [
  "lista aplikacji"
 ,"listy aplikacji"
 ,"list aplikacji"

]
, "Number"
: "Ilość"

, "Unit"
: "Jednostka"

, "Unit Price"
: "Cena jednostkowa"

, "Timesheets are billable"
: "Karty godzin gotowe do przeliczenia"

, "closed"
: "zakończone"

, "open"
: "otwarte"

, "Billed"
: "Przeliczone"

, "not yet billed"
: "jeszcze nie przeliczone"

, "to bill"
: "przelicz"

, "billed"
: "przeliczone"

, "example record"
: "Przykładowy wiersz"

, "example record list"
: "Lista przykładowych wierszy"

, "record list"
: "lista aplikacji"

}));

==> tine20-exampleapplication_2017.08.11.tar.bz2: ExampleApplication/js/ExampleApplication-lang-pl-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0 - ExampleApplication\nReport-Msgid-Bugs-To: \nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2012-03-02 13:06+0000\nLast-Translator: Wojciech Kaczmarek <Unknown>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Launchpad-Export-Date: 2012-03-03 05:53+0000\nX-Generator: Launchpad (build 14886)\nX-Poedit-Language: Polish\nX-Poedit-SourceCharset: utf-8\n"

, "ExampleRecord"
: "Przykładowy wiersz"

, "Name"
: "Nazwa"

, "Status"
: "Status"

, "Reason"
: ""

, "Total Example Records"
: ""

, "New Example"
: ""

, "Status Available"
: "Status Dostępny"

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: "Możliwy status. Zauważ proszę, że dodatkowy status może wpływać w innych przykładowych aplikacjach na eksport albo synchronizację."

, "Completed"
: "Zakończone"

, "Cancelled"
: "Anulowane"

, "In process"
: "W opracowaniu"

, "Reasons Available"
: ""

, "Possible status reasons."
: ""

, "Change"
: ""

, "Documentation"
: ""

, "Requirement Changed"
: ""

, "Not Possible"
: ""

, "Implementation"
: ""

, "Review"
: ""

, "Integration"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Example String"
: ""

, "Just an example string for test purpose"
: ""

, "ExampleApplication"
: "Przykładowa aplikacja"

, "example record, example records"
: [
  "Przykładowy wiersz"
 ,"przykładowe wiersze"
 ,"przykładowe wiersze"

]
, "example records"
: ""

, "example record list"
: "Lista przykładowych wierszy"

, "example record lists"
: ""

, "Number"
: "Ilość"

, "Default Example Record Container"
: ""

, "The default container for new records"
: ""

























, "example record"
: "Przykładowy wiersz"

}));
